==> jc-1.4.0.tar.gz: java/awt/im/InputSubset.h <==
// public final class java.awt.im.InputSubset

// class file dependencies
// @dep_class e0c0443e21794710 java_awt_im_InputSubset
// @dep_class 5a3b83efc151abe9 java_lang_Character__24Subset
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Character__24Subset

#include "java/lang/Character__24Subset.h"

#ifndef _JC_java_awt_im_InputSubset_H_
#define _JC_java_awt_im_InputSubset_H_

// Forward structure declarations
struct _jc_java_awt_im_InputSubset$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_im_InputSubset$sub_refs	_jc_java_awt_im_InputSubset$sub_refs;
typedef struct _jc_java_awt_im_InputSubset$sub_nonrefs	_jc_java_awt_im_InputSubset$sub_nonrefs;
typedef struct _jc_java_awt_im_InputSubset$refs	_jc_java_awt_im_InputSubset$refs;
typedef struct _jc_java_awt_im_InputSubset$nonrefs	_jc_java_awt_im_InputSubset$nonrefs;
typedef struct _jc_java_awt_im_InputSubset$object	_jc_java_awt_im_InputSubset$object;

typedef struct _jc_java_awt_im_InputSubset$fields_struct	_jc_java_awt_im_InputSubset$fields_struct;
typedef const struct _jc_java_awt_im_InputSubset$vmethods	_jc_java_awt_im_InputSubset$vmethods;
typedef const struct _jc_java_awt_im_InputSubset$vtable	_jc_java_awt_im_InputSubset$vtable;
typedef const struct _jc_java_awt_im_InputSubset$vtype	_jc_java_awt_im_InputSubset$vtype;

// Class fields structure
struct _jc_java_awt_im_InputSubset$fields_struct {
	struct _jc_java_awt_im_InputSubset$object	*FULLWIDTH__5fDIGITS;
	struct _jc_java_awt_im_InputSubset$object	*FULLWIDTH__5fLATIN;
	struct _jc_java_awt_im_InputSubset$object	*HALFWIDTH__5fKATAKANA;
	struct _jc_java_awt_im_InputSubset$object	*HANJA;
	struct _jc_java_awt_im_InputSubset$object	*KANJI;
	struct _jc_java_awt_im_InputSubset$object	*LATIN;
	struct _jc_java_awt_im_InputSubset$object	*LATIN__5fDIGITS;
	struct _jc_java_awt_im_InputSubset$object	*SIMPLIFIED__5fHANZI;
	struct _jc_java_awt_im_InputSubset$object	*TRADITIONAL__5fHANZI;
};
extern _jc_java_awt_im_InputSubset$fields_struct _jc_java_awt_im_InputSubset$class_fields;

// Constructors
extern void _jc_java_awt_im_InputSubset$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_im_InputSubset$object *, struct _jc_java_lang_String$object *);

// Static methods
extern void _jc_java_awt_im_InputSubset$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_im_InputSubset$vmethods {
};

// Vtable
struct _jc_java_awt_im_InputSubset$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Character__24Subset$vmethods	java_lang_Character__24Subset;
	_jc_java_awt_im_InputSubset$vmethods	java_awt_im_InputSubset;
};

// Vtype
struct _jc_java_awt_im_InputSubset$vtype {
	_jc_type			type;
	_jc_java_awt_im_InputSubset$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_im_InputSubset$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_im_InputSubset$refs {
    _jc_java_awt_im_InputSubset$sub_refs	java_awt_im_InputSubset;
    _jc_java_lang_Character__24Subset$sub_refs	java_lang_Character__24Subset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_im_InputSubset$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_im_InputSubset$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Character__24Subset$sub_nonrefs	java_lang_Character__24Subset;
    _jc_java_awt_im_InputSubset$sub_nonrefs	java_awt_im_InputSubset;
};

// Object instance structure
struct _jc_java_awt_im_InputSubset$object {
	_jc_java_awt_im_InputSubset$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_im_InputSubset$vtype	*vtype;
	_jc_java_awt_im_InputSubset$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_im_InputSubset$vtype _jc_java_awt_im_InputSubset$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_im_InputSubset, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_im_InputSubset$class_object;

#endif	/* _JC_java_awt_im_InputSubset_H_ */

==> jc-1.4.6.tar.gz: java/awt/im/InputSubset.h <==
// public final class java.awt.im.InputSubset

// class file dependencies
// @dep_class e0c0443e21794710 java_awt_im_InputSubset
// @dep_class 5a3b83efc151abe9 java_lang_Character__24Subset
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Character__24Subset

#include "java/lang/Character__24Subset.h"

#ifndef _JC_java_awt_im_InputSubset_H_
#define _JC_java_awt_im_InputSubset_H_

// Forward structure declarations
struct _jc_java_awt_im_InputSubset$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_im_InputSubset$sub_refs	_jc_java_awt_im_InputSubset$sub_refs;
typedef struct _jc_java_awt_im_InputSubset$sub_nonrefs	_jc_java_awt_im_InputSubset$sub_nonrefs;
typedef struct _jc_java_awt_im_InputSubset$refs	_jc_java_awt_im_InputSubset$refs;
typedef struct _jc_java_awt_im_InputSubset$nonrefs	_jc_java_awt_im_InputSubset$nonrefs;
typedef struct _jc_java_awt_im_InputSubset$object	_jc_java_awt_im_InputSubset$object;

typedef struct _jc_java_awt_im_InputSubset$fields_struct	_jc_java_awt_im_InputSubset$fields_struct;
typedef const struct _jc_java_awt_im_InputSubset$vmethods	_jc_java_awt_im_InputSubset$vmethods;
typedef const struct _jc_java_awt_im_InputSubset$vtable	_jc_java_awt_im_InputSubset$vtable;
typedef const struct _jc_java_awt_im_InputSubset$vtype	_jc_java_awt_im_InputSubset$vtype;

// Class fields structure
struct _jc_java_awt_im_InputSubset$fields_struct {
	struct _jc_java_awt_im_InputSubset$object	*FULLWIDTH__5fDIGITS;
	struct _jc_java_awt_im_InputSubset$object	*FULLWIDTH__5fLATIN;
	struct _jc_java_awt_im_InputSubset$object	*HALFWIDTH__5fKATAKANA;
	struct _jc_java_awt_im_InputSubset$object	*HANJA;
	struct _jc_java_awt_im_InputSubset$object	*KANJI;
	struct _jc_java_awt_im_InputSubset$object	*LATIN;
	struct _jc_java_awt_im_InputSubset$object	*LATIN__5fDIGITS;
	struct _jc_java_awt_im_InputSubset$object	*SIMPLIFIED__5fHANZI;
	struct _jc_java_awt_im_InputSubset$object	*TRADITIONAL__5fHANZI;
};
extern _jc_java_awt_im_InputSubset$fields_struct _jc_java_awt_im_InputSubset$class_fields;

// Constructors
extern void _jc_java_awt_im_InputSubset$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_im_InputSubset$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_im_InputSubset$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_im_InputSubset$vmethods {
};

// Vtable
struct _jc_java_awt_im_InputSubset$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Character__24Subset$vmethods	java_lang_Character__24Subset;
	_jc_java_awt_im_InputSubset$vmethods	java_awt_im_InputSubset;
};

// Vtype
struct _jc_java_awt_im_InputSubset$vtype {
	_jc_type			type;
	_jc_java_awt_im_InputSubset$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_im_InputSubset$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_im_InputSubset$refs {
    _jc_java_awt_im_InputSubset$sub_refs	java_awt_im_InputSubset;
    _jc_java_lang_Character__24Subset$sub_refs	java_lang_Character__24Subset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_im_InputSubset$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_im_InputSubset$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Character__24Subset$sub_nonrefs	java_lang_Character__24Subset;
    _jc_java_awt_im_InputSubset$sub_nonrefs	java_awt_im_InputSubset;
};

// Object instance structure
struct _jc_java_awt_im_InputSubset$object {
	_jc_java_awt_im_InputSubset$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_im_InputSubset$vtype	*vtype;
	_jc_java_awt_im_InputSubset$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_im_InputSubset$vtype _jc_java_awt_im_InputSubset$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_im_InputSubset, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_im_InputSubset$class_object;

#endif	/* _JC_java_awt_im_InputSubset_H_ */
